.. _contribute:

Contribute
==========

This project is developed and maintained by the `ODISSEI Social Data Science (SoDa) <https://odissei-data.nl/nl/soda/>`_ team and the `FIRMBACKBONE <https://firmbackbone.nl/>`_ Project.

.. image:: https://avatars.githubusercontent.com/u/71822308?s=200&v=4
   :alt: SoDa logo
   :width: 200px
   :align: center

Any contributions you make to WebSweep are **greatly appreciated**.

How to Contribute
-----------------

Whether you're fixing a bug, adding a new feature, or improving the documentation, your contribution is welcome. For more information on how to report issues, submit pull requests, and contribute to WebSweep in general, please see our `CONTRIBUTING <https://github.com/sodascience/websweep/blob/main/CONTRIBUTING.md>`_ file.

The contribution file outlines the process we'd like contributors to follow to help maintain the quality and consistency of the project.

Developing WebSweep
-------------------

For instructions on how to run WebSweep without installing it and how to install it from source, please refer to our `DEVELOPMENT <https://github.com/sodascience/websweep/blob/main/DEVELOPMENT.md>`_ guide. This guide provides all the necessary steps to get you started with developing and testing WebSweep on your local environment.

Contact and Support
-------------------

If you have any questions or need support, feel free to reach out. You can file an issue in our `issue tracker <https://github.com/sodascience/websweep/issues>`_ or contact the team directly through the `ODISSEI SoDa contact form <https://odissei-data.nl/en/using-soda/>`_.
